@@ -94,6 +94,10 @@ INSTANCE_GROUPS_SCHEMA = {
                 "for the instance group",
                 "required": True
             },
+            "CustomAmiId": {
+                "type": "string",
+                "description": "The AMI ID of a custom AMI to use when Amazon EMR provisions EC2 instances."
+            },
             "EbsConfiguration": {
                 "type": "object",
                 "description": "EBS configuration that will be associated with the instance group.",
@@ -124,6 +128,10 @@ INSTANCE_GROUPS_SCHEMA = {
                                         "Iops": {
                                             "type": "integer",
                                             "description": "The IOPS of the EBS volume that is attached to all the instances in the instance group.",
+                                        },
+                                        "Throughput": {
+                                            "type": "integer",
+                                            "description": "The throughput of the EBS volume that is attached to all the instances in the instance group.",
                                         }
                                     }
                                 },
@@ -331,6 +339,10 @@ INSTANCE_FLEETS_SCHEMA = {
                             "type": "double",
                             "description": "Bid price as percentage of on-demand price."
                         },
+                        "CustomAmiId": {
+                            "type": "string",
+                            "description": "The AMI ID of a custom AMI to use when Amazon EMR provisions EC2 instances."
+                        },
                         "EbsConfiguration": {
                             "type": "object",
                             "description": "EBS configuration that is associated with the instance group.",
@@ -366,6 +378,11 @@ INSTANCE_FLEETS_SCHEMA = {
                                                         "type": "integer",
                                                         "description": "The IOPS of the EBS volume that is attached to "
                                                             "all the instances in the instance group.",
+                                                    },
+                                                    "Throughput": {
+                                                         "type": "integer",
+                                                         "description": "The throughput of the EBS volume that is attached to "
+                                                             "all the instances in the instance group.",
                                                     }
                                                 }
                                             },
@@ -393,6 +410,28 @@ INSTANCE_FLEETS_SCHEMA = {
                                 "type": "string",
                                 "description": "The strategy to use in launching On-Demand instance fleets.",
                                 "enum": ["lowest-price"]
+                            },
+                            "CapacityReservationOptions": {
+                                "type": "object",
+                                "properties" : {
+                                    "UsageStrategy": {
+                                        "type": "string",
+                                        "description": "The strategy of whether to use unused Capacity Reservations for fulfilling On-Demand capacity.",
+                                        "enum": ["use-capacity-reservations-first"]
+                                    },
+                                    "CapacityReservationPreference": {
+                                        "type": "string",
+                                        "description": "The preference of the instance's Capacity Reservation.",
+                                        "enum": [
+                                            "open",
+                                            "none"
+                                        ]
+                                    },
+                                    "CapacityReservationResourceGroupArn": {
+                                        "type": "string",
+                                        "description": "The ARN of the Capacity Reservation resource group in which to run the instance."
+                                    }
+                                }
                             }
                         }
                     },
@@ -793,3 +832,15 @@ PLACEMENT_GROUP_CONFIGS_SCHEMA = {
         }
     }
 }
+
+AUTO_TERMINATION_POLICY_SCHEMA = {
+    "type": "object",
+    "properties":  {
+        "IdleTimeout": {
+            "type": "long",
+            "description":
+                "Specifies the amount of idle time in seconds after which the cluster automatically terminates. "
+                "You can specify a minimum of 60 seconds and a maximum of 604800 seconds (seven days).",
+        }
+    }
+}
